@@ -1,6 +1,6 @@
 from typing import Callable, TypeVar, Union
 
-from .models import ParameterSpecification
+from . import models
 from .sentinels import Missing, MissingType
 
 T = TypeVar("T")
@@ -10,5 +10,5 @@ def Param(
     *,
     default: Union[T, MissingType] = Missing,
     default_factory: Union[Callable[[], T], MissingType] = Missing
-) -> ParameterSpecification[T]:
-    return ParameterSpecification(default=default, default_factory=default_factory)
+) -> models.Param[T]:
+    return models.Param(default=default, default_factory=default_factory)
